@@ -606,7 +606,7 @@ function remove_tokens($tokens_string) {
 	return [$result_code, $result_output];
 }
 function remove_tags($tags_string, $comma_separated_tags=false) {
-	$tags_arg = '--tags=' . escapeshellarg($tags_string);
+	$tags_arg = '--tags=' . escapeshellarg(format_tags_string($tags_string));
 	$comma_separated_tags_arg = '';
 	if ($comma_separated_tags) {
 		$comma_separated_tags_arg = ' --comma-separated-tags';
@@ -617,8 +617,8 @@ function remove_tags($tags_string, $comma_separated_tags=false) {
 	return [$result_code, $result_output];
 }
 function replace_tag($old_tag, $new_tag) {
-	$old_tag_arg = ' --old-tag=' . escapeshellarg($old_tag);
-	$new_tag_arg = ' --new-tag=' . escapeshellarg($new_tag);
+	$old_tag_arg = ' --old-tag=' . escapeshellarg(format_tags_string($old_tag));
+	$new_tag_arg = ' --new-tag=' . escapeshellarg(format_tags_string($new_tag));
 	$result_code = null;
 	$result_output = null;
 	exec(THALASSA_CMD . ' --replace-tag' . $old_tag_arg . $new_tag_arg, $result_output, $result_code);
@@ -627,8 +627,8 @@ function replace_tag($old_tag, $new_tag) {
 function accompany_tag($tag, $new_tag) {
 	#TODO remove early return when accompany_tag is finished in thalassa.py
 	return
-	$tag_arg = ' --tag=' . escapeshellarg($tag);
-	$new_tag_arg = ' --new-tag=' . escapeshellarg($new_tag);
+	$tag_arg = ' --tag=' . escapeshellarg(format_tags_string($tag));
+	$new_tag_arg = ' --new-tag=' . escapeshellarg(format_tags_string($new_tag));
 	$result_code = null;
 	$result_output = null;
 	exec(THALASSA_CMD . ' --accompany-tag' . $tag_arg . $new_tag_arg, $result_output, $result_code);
@@ -683,8 +683,7 @@ function process_temp_files(
 		$filenames_string = implode(THALASSA_FILEPATHS_SEPARATOR, $filenames);
 		$filenames_arg = ' --filenames=' . escapeshellarg($filenames_string);
 	}
-
-	$tags_arg = ' --tags=' . escapeshellarg($tags_string . $additional_tags);
+	$tags_arg = ' --tags=' . escapeshellarg(format_tags_string($tags_string . $additional_tags));
 
 	$result_code = null;
 	$result_output = null;
@@ -756,7 +755,7 @@ function set_publish_time($file_ids_string, $datetime_string) {
 }
 function edit_files_tags($file_ids_string, $mode, $tags_string='', $comma_separated_tags=False) {
 	$file_ids_arg = ' --file-ids=' . escapeshellarg($file_ids_string);
-	$tags_arg = ' --tags=' . escapeshellarg($tags_string);
+	$tags_arg = ' --tags=' . escapeshellarg(format_tags_string($tags_string));
 	if (in_array($mode, ['replace', 'remove', 'add'])) {
 		$mode = ' --' . $mode;
 	}
