@@ -3,6 +3,7 @@ function render_page_header($page_title, $page_id='', $opengraph=[], $misc='') {
 	$page_title = CONFIG['site_title'] . ' - ' . $page_title;
 	$page_title = str_replace('"', '&quot;', $page_title);
 
+	$static_files_version = '2025-08-13_1027';
 	$res = '<!doctype html>
 <html 
 	lang="en" 
@@ -46,16 +47,16 @@ function render_page_header($page_title, $page_id='', $opengraph=[], $misc='') {
 		<meta name="helper" content="1"/>';
 		}
 	}
-	$res .= '<style type="text/css">@import \'' . STATIC_URI . 'style/theme.css\';</style>';
+	$res .= '<style type="text/css">@import \'' . STATIC_URI . 'style/theme.css?' . $static_files_version . '\';</style>';
 	foreach (['general', 'tables', 'forms', 'depth', 'layout', 'topmenu', 'tags', 'files', 'script'] as $stylesheet) {
-		$res .= '<link rel="stylesheet" type="text/css" href="' . STATIC_URI . 'style/' . $stylesheet . '.css"/>';
+		$res .= '<link rel="stylesheet" type="text/css" href="' . STATIC_URI . 'style/' . $stylesheet . '.css?' . $static_files_version . '"/>';
 	}
-	$res .= '<link rel="stylesheet" type="text/css" href="custom/style.css"/>';
+	$res .= '<link rel="stylesheet" type="text/css" href="custom/style.css?' . $static_files_version . '"/>';
 	$res .= '<script type="text/javascript">document.documentElement.classList.add(\'scripts-enabled\');</script>';
 	foreach (['general', 'preferences'] as $script) {	#, 'string_format'
-		$res .= '<script type="text/javascript" src="' . STATIC_URI . 'script/' . $script . '.js"></script>';
+		$res .= '<script type="text/javascript" src="' . STATIC_URI . 'script/' . $script . '.js?' . $static_files_version . '"></script>';
 	}
-	$res .= '<script type="module" src="custom/script.js"></script>' . $misc . '
+	$res .= '<script type="module" src="custom/script.js?' . $static_files_version . '"></script>' . $misc . '
 	</head>
 	<body id="endpoint-' . $page_id . '">
 		<nav id="topmenu">
